Introduction
============

The ``debops.root_account`` Ansible role can be used to manage the system root
account and generate SSH private keys for use on other hosts.

Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.0.0``. To install it, run:

.. code-block:: console

   ansible-galaxy install debops.root_account

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
